@@ -1,7 +1,7 @@
 /*
  * weechat-perl.c - perl plugin for WeeChat
  *
- * Copyright (C) 2003-2024 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2025 Sébastien Helleu <flashcode@flashtux.org>
  * Copyright (C) 2005-2008 Emmanuel Bouthenot <kolter@openics.org>
  *
  * This file is part of WeeChat, the extensible chat client.
@@ -233,11 +233,10 @@ weechat_perl_hash_to_hashtable (SV *hash, int size, const char *type_keys,
  */
 
 void
-weechat_perl_output_flush ()
+weechat_perl_output_flush (void)
 {
     const char *ptr_command;
     char *temp_buffer, *command;
-    int length;
 
     if (!(*perl_buffer_output)[0])
         return;
@@ -266,12 +265,11 @@ weechat_perl_output_flush ()
             }
             else
             {
-                length = 1 + strlen (temp_buffer) + 1;
-                command = malloc (length);
-                if (command)
+                if (weechat_asprintf (&command,
+                                      "%c%s",
+                                      temp_buffer[0],
+                                      temp_buffer) >= 0)
                 {
-                    snprintf (command, length, "%c%s",
-                              temp_buffer[0], temp_buffer);
                     weechat_command (perl_eval_buffer,
                                      (command[0]) ? command : " ");
                     free (command);
@@ -334,7 +332,7 @@ weechat_perl_exec (struct t_plugin_script *script,
     char *func;
     unsigned int count;
     void *ret_value;
-    int *ret_i, mem_err, length, i, argc;
+    int *ret_i, mem_err, i, argc;
     SV *ret_s;
     HV *hash;
     struct t_plugin_script *old_perl_current_script;
@@ -346,20 +344,19 @@ weechat_perl_exec (struct t_plugin_script *script,
     perl_current_script = script;
 
 #ifdef MULTIPLICITY
-    (void) length;
     func = (char *) function;
     old_context = PERL_GET_CONTEXT;
     if (script->interpreter)
         PERL_SET_CONTEXT (script->interpreter);
 #else
-    length = strlen ((script->interpreter) ? script->interpreter : perl_main) +
-        strlen (function) + 3;
-    func = (char *) malloc (length);
-    if (!func)
+    if (weechat_asprintf (
+            &func,
+            "%s::%s",
+            (char *) ((script->interpreter) ? script->interpreter : perl_main)
+            function) < 0)
+    {
         return NULL;
-    snprintf (func, length, "%s::%s",
-              (char *) ((script->interpreter) ? script->interpreter : perl_main),
-              function);
+    }
 #endif /* MULTIPLICITY */
 
     dSP;
@@ -511,12 +508,9 @@ weechat_perl_exec (struct t_plugin_script *script,
 struct t_plugin_script *
 weechat_perl_load (const char *filename, const char *code)
 {
-    char str_warning[512], str_error[512];
-
+    char str_warning[512], str_error[512], *perl_code;
     struct t_plugin_script temp_script;
     struct stat buf;
-    char *perl_code;
-    int length;
 #ifdef MULTIPLICITY
     int wcwidth160;
 #else
@@ -579,43 +573,41 @@ weechat_perl_load (const char *filename, const char *code)
     wcwidth160 = wcwidth (160);
     perl_construct (perl_current_interpreter);
 
+#if PERL_REVISION >= 6 || (PERL_REVISION == 5 && PERL_VERSION >= 28) || (PERL_REVISION == 5 && PERL_VERSION == 27 && PERL_SUBVERSION >= 9)
     if (wcwidth (160) != wcwidth160)
     {
         /* restore the locale that's broken in some versions of Perl */
         Perl_setlocale (LC_ALL, "");
     }
+#else
+    (void) wcwidth160;
+#endif
 
     temp_script.interpreter = (PerlInterpreter *) perl_current_interpreter;
     perl_parse (perl_current_interpreter, weechat_perl_api_init,
                 perl_args_count, perl_args, NULL);
-    length = strlen (perl_weechat_code) + strlen (str_warning) +
-        strlen (str_error) - 2 + 4 + strlen ((code) ? code : filename) + 4 + 1;
-    perl_code = malloc (length);
-    if (!perl_code)
-        return NULL;
-    snprintf (perl_code, length, perl_weechat_code,
-              str_warning,
-              str_error,
-              (code) ? "{\n" : "'",
-              (code) ? code : filename,
-              (code) ? "\n};\n" : "';");
+    weechat_asprintf (&perl_code,
+                      perl_weechat_code,
+                      str_warning,
+                      str_error,
+                      (code) ? "{\n" : "'",
+                      (code) ? code : filename,
+                      (code) ? "\n};\n" : "';");
 #else
     snprintf (pkgname, sizeof (pkgname), "%s%d", PKG_NAME_PREFIX, perl_num);
     perl_num++;
-    length = strlen (perl_weechat_code) + strlen (str_warning) +
-        strlen (str_error) - 4 + strlen (pkgname) + 4 +
-        strlen ((code) ? code : filename) + 4 + 1;
-    perl_code = malloc (length);
+    weechat_asprintf (&perl_code,
+                      perl_weechat_code,
+                      pkgname,
+                      str_warning,
+                      str_error,
+                      (code) ? "{\n" : "'",
+                      (code) ? code : filename,
+                      (code) ? "\n};\n" : "';");
+#endif /* MULTIPLICITY */
+
     if (!perl_code)
         return NULL;
-    snprintf (perl_code, length, perl_weechat_code,
-              pkgname,
-              str_warning,
-              str_error,
-              (code) ? "{\n" : "'",
-              (code) ? code : filename,
-              (code) ? "\n};\n" : "';");
-#endif /* MULTIPLICITY */
     eval_pv (perl_code, TRUE);
     free (perl_code);
 
@@ -792,7 +784,7 @@ weechat_perl_unload_name (const char *name)
  */
 
 void
-weechat_perl_unload_all ()
+weechat_perl_unload_all (void)
 {
     while (perl_scripts)
     {
@@ -1320,11 +1312,15 @@ weechat_plugin_init (struct t_weechat_plugin *plugin, int argc, char *argv[])
     wcwidth160 = wcwidth (160);
     perl_construct (perl_main);
 
+#if PERL_REVISION >= 6 || (PERL_REVISION == 5 && PERL_VERSION >= 28) || (PERL_REVISION == 5 && PERL_VERSION == 27 && PERL_SUBVERSION >= 9)
     if (wcwidth (160) != wcwidth160)
     {
         /* restore the locale that's broken in some versions of Perl */
         Perl_setlocale (LC_ALL, "");
     }
+#else
+    (void) wcwidth160;
+#endif
 
     perl_parse (perl_main, weechat_perl_api_init, perl_args_count,
                 perl_args, NULL);
